summaryrefslogtreecommitdiff
path: root/src/settings.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/settings.h')
-rw-r--r--src/settings.h23
1 files changed, 20 insertions, 3 deletions
diff --git a/src/settings.h b/src/settings.h
index 484ce163..5f6dd37c 100644
--- a/src/settings.h
+++ b/src/settings.h
@@ -626,10 +626,22 @@ public:
bool collapsibleSeparators(Qt::SortOrder order) const;
void setCollapsibleSeparators(bool ascending, bool descending);
// whether to display mod conflicts on separators when collapsed
//
- bool collapsibleSeparatorsConflicts() const;
- void setCollapsibleSeparatorsConflicts(bool b);
+ bool collapsibleSeparatorsHighlightTo() const;
+ void setCollapsibleSeparatorsHighlightTo(bool b);
+
+ // whether to highlight mod conflicts and plugins from separators
+ // when selected but collapsed
+ //
+ bool collapsibleSeparatorsHighlightFrom() const;
+ void setCollapsibleSeparatorsHighlightFrom(bool b);
+
+ // whether to show icons on collapsed separators
+ //
+ bool collapsibleSeparatorsIcons(int column) const;
+ void setCollapsibleSeparatorsIcons(int column, bool show);
// whether each profile should have its own expansion state
//
@@ -651,6 +663,11 @@ public:
bool metaDownloads() const;
void setMetaDownloads(bool b);
+ // whether to hide downloads after installing them
+ //
+ bool hideDownloadsAfterInstallation() const;
+ void setHideDownloadsAfterInstallation(bool b);
+
// whether the API counter should be hidden
//
bool hideAPICounter() const;
@@ -626,10 +626,22 @@ public:
bool collapsibleSeparators(Qt::SortOrder order) const;
void setCollapsibleSeparators(bool ascending, bool descending);
- // whether to display mod conflicts on separators when collapsed
+ // whether to highlight mod conflicts and plugins on collapsed
+ // separators
//